Class: SOAP::Mapping::Object
- Inherits:
- BasicObject
- Defined in:
- lib/mappum/open_xml_object.rb
Direct Known Subclasses
Instance Method Summary collapse
-
#==(other) ⇒ Object
XmlAny element is equal to the other xmlAny element when it has same elements and attributes regardles of ordering of elements and attributes.
- #id ⇒ Object
- #type ⇒ Object
Instance Method Details
#==(other) ⇒ Object
XmlAny element is equal to the other xmlAny element when it has same elements and attributes regardles of ordering of elements and attributes.
14 15 16 17 18 19 |
# File 'lib/mappum/open_xml_object.rb', line 14 def == other return false if other.class != self.class return false if @__xmlele - other.__xmlele == [] return false if @__xmlattr != other.__xmlattr return true end |
#id ⇒ Object
2 3 4 |
# File 'lib/mappum/open_xml_object.rb', line 2 def id self[XSD::QName.new(nil, "id")] end |
#type ⇒ Object
5 6 7 |
# File 'lib/mappum/open_xml_object.rb', line 5 def type self[XSD::QName.new(nil, "type")] end |